# Lance-Ray

[![PyPI](https://img.shields.io/pypi/v/lance-ray.svg)](https://pypi.org/project/lance-ray/)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)
[![Documentation](https://img.shields.io/badge/docs-latest-brightgreen.svg)](https://lancedb.github.io/lance/integrations/ray)

A Python library that provides seamless integration between 
[Ray](https://ray.io/) and [Lance](https://lancedb.github.io/lance/) for distributed columnar data processing.

- [Documentation](https://lancedb.github.io/lance-ray/)
- [Contributing Guide and Dev Setup](./CONTRIBUTING.md)

## Quick Start





## API Reference

### I/O Functions


